=====
Usage
=====

Once you follow the :doc:`installation` process you can take and share an 
screenshot simply doing.

1. Press ``super + shift + 5``.
2. Save in the editor ``ctrl + s``.
3. Then click on the icon in the indicator and select copy either rst, direct
   link or md.

    .. image:: http://screenshots.vauxoo.com/oem/72a459-709x216.png
       :width: 400
       
4. If you select ``View in Folder``, your File broser will be open in the folder
   you are supervising to review your files created.
5. You can save files manually on this folder and they will be uploaded
   automatically also, that's pretty usefull when you use a different origin 
   of images.
   
.. Note::
    if some of this features is not working as expected/wanted you can read how
    contribute with a good issue report in the :ref:`contributing-all` section
    reporting an issue.

